@@ -1,5 +1,6 @@
 import argparse
 import json
+from pathlib import Path
 
 from azureml.core import Dataset, Run
 from chunk_files import chunk_files
@@ -34,7 +35,15 @@ for dataset in datasets:
     print(
         f"Retrieve raw data in dataset: {raw_dataset.name} - version: {raw_dataset.version}"
     )
-    raw_dataset.as_mount("/mnt/input_data")
-    chunk_files(raw_dataset, raw_data_dir, number_chunk, shutil.copy, [chunk_index], dataset_directory)
+    if number_chunk == 1:
+        chunk_name = "chunk0"
+        if dataset_directory is None or dataset_directory == "":
+            dir_path = Path(str(Path(raw_data_dir) / chunk_name))
+        else:
+            dir_path = Path(str(Path(raw_data_dir) / chunk_name / dataset_directory))
+        dataset.download(target_path=dir_path, overwrite=False)
+    else:
+        raw_dataset.as_mount("/mnt/input_data")
+        chunk_files(raw_dataset, raw_data_dir, number_chunk, shutil.copy, [chunk_index], dataset_directory)
 
 
