@@ -38,7 +38,7 @@ def save_step(
         compute_target=compute_target,
         runconfig=run_config,
         source_directory=Path(__file__).resolve().parent,
-        allow_reuse=True,
+        allow_reuse=False,
     )
 
     return step
